..
    Copyright (C) 2022 Graz University of Technology.

    invenio-moodle is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version v1.1.1 (release 2025-05-22)

- fix(wip): application profile 2


Version v1.1.0 (release 2025-04-29)

- tasks: improve wording
- fix: DeprecationWarning
- chore: maintenance
- setup: add python3.13 support
- global: add jobs


Version v1.0.0 (release 2024-07-04)

- global: clean up missed steps from restructering
- schema: make the schema compatible with 2.0
- cli: change needed for global-search
- cli: simplify command
- refactor: record/service and connector structure


Version v0.2.3 (release 2023-11-10)

- global: migrate to invenio-i18n


Version v0.2.2 (release 2023-07-25)

- setup: fix typo, prevent correct build


Version v0.2.1 (release 2023-07-25)

- setup: change to reusable workflows


Version v0.2.0 (release 2023-07-25)



